/* 
 * NATOW - Tank to tank warfare in a 3D fully destructable world
 *
 * Copyright (C) 2000-2001
 *                     Robert Ancell  <bob27@users.sourceforge.net>
 *                     Yannick Perret <hexasoft@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/* about.c
   Code for about screen */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "about.h"
#include "world.h"
#include "2d.h"
#include "update.h"
#include "input.h"
#include "cursor.h"
#include "plasma.h"
#include "text.h"
#include "tools.h"
#include "display_stack.h"
#include "glut_interface.h"

/* the text to be displayed */
char *about_text[] = {
  " ",
  "N.A.T.O.W",
  " ",
  "#j",
  " ",
  "#l coded by #l",
  " ",
  "neutronium (Robert Ancell)",
  "#f",
  "hexasoft (Yannick Perret)",
  "#f",
  "extropy (Joel Pitt)",
  "#f",
  "mtl (David Crompton)",
  " ",
  "#m",
  " ",
  "N.A.T.O.W is a 3D tank game based",
  "loosely on scorched earth, but",
  "including a single player element.",
  "The goal is to kill the other tanks",
  "and as much terrain as possible.",
  "",
  "#b",
  "",
  "#w Report bugs to #w",
  "natow-devel@lists.sourceforge.net",
  "",
  "#e",
  "",
  "Two game modes are available:",
  "",
  "Turn-based, where each player chooses",
  "to fire or to move, until death",
  "",
  "Single player, where you are alone",
  "against AI-controled players in",
  "real-time. This means that you can move",
  "and fire as you whish (until death)",
  "",
  "",
  "#c have fun! #c",
  "",
  NULL,
};




/* init the about screen */
void init_about(World *world)
{
  Nprintf("Initializing about screen...\n");

  Nprintf("About screen ready.\n");
}

/* free about system */
void free_about(World *world)
{/* nothing here at this time */
}

/* manage key actions for the about screen */
void manage_about_input(World *world, int key)
{
  if(key == KEY_SPACE || key == KEY_RETURN || key == KEY_MOUSE1 || key == KEY_ESC)
  {
    /* Go back to the old display */
    pop_display_mode(world);
  }
}

/* manage about screen drawing */
void draw_about(World *world)
{
  static float last_time = 0.;
  int i;
  float dt;
  /* text related */
  static int current_line = 0;
  static float current_scroll = 0.;
  float lh;

  activate_2d();

  draw_plasma(world);

  dt = world->total_elapsed_time - last_time;
  last_time = world->total_elapsed_time;
  if (dt > 1.)
    dt = 1.;

  set_2d_transparency(1.);

  /* draw surrounding box */
  draw_2d_box(1, 1, 98, 98, 0);


  /* manage text displaying */
  lh = get_2d_letter_height(0);
  if (about_text[current_line] == NULL)
    {/* restart */
    current_line = 0;
    current_scroll = 0.;
    }
  for(i=0; i<18; i++)
    {
    if (about_text[current_line+i] == NULL)
      break;
    draw_2d_text_center(about_text[current_line+i], 0., 100.,
                   100 - (13+i*(lh+0.1)-current_scroll), 0, 0);
    }
  current_scroll += 2.9*dt;

  if (current_scroll > lh)
    {
    current_scroll = 0.;
    current_line++;
    }


  deactivate_2d();
}
