/* 
 * NATOW - Tank to tank warfare in a 3D fully destructable world
 *
 * Copyright (C) 2000-2001
 *                     Robert Ancell  <bob27@users.sourceforge.net>
 *                     Yannick Perret <hexasoft@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __glut_interface_h_
#define __glut_interface_h_

#include <GL/glut.h>

#include "world.h"

/* Mouse defines */
enum {LEFT_BUTTON = 0, MIDDLE_BUTTON, RIGHT_BUTTON};
#define MOUSE_UP TRUE
#define MOUSE_DOWN FALSE

/* Initialize glut */
void init_glut(int *argc, char **argv);

/* Make a window for natow */
void make_glut_window(int w, int h);

/* Reshape the window */
void reshape_glut_window(int w, int h);

/* Go to fullscreen mode */
void fullscreen_glut(void);

/* Move the window */
void move_glut_window(int x, int y);

/* Set the world for glut (can't pass it to any of glut's functions) */
void set_glut_world(World *world);

/* Attach the required functions to glut */
void update_glut_functions(World *world);

/* Force the window to refresh */
#define post_redisplay() glutPostRedisplay()

/* Swap the buffers, i.e. display _now_ */
#define swap_buffers() glutSwapBuffers()

/* Whenever the window needs to be redrawn */
void glut_display(void);

/* Whenever the window is resized */
void glut_reshape(int w, int h);

/* The function that gets called for each extended keyboard event
   (for example arrow keys) */
void glut_ext_keyboard(int key, int x, int y);

/* The function that gets called for each keyboard event */
void glut_keyboard(unsigned char key, int x, int y);

/* The function that gets called for each mouse movements */
void glut_move(int x, int y);

/* The function that gets called for each enter/leave for the window */
void glut_enter_leave(int state);

/* The function that gets called for each mouse click event */
void glut_mouse(int button, int state, int x, int y);

/* The function that gets called for each mouse motion event */
void glut_motion(int x, int y);

/* Get the current states of the buttons
   returns 3 entry array of states for each button */
int *get_button_states(void);

/* The function that gets called for each idle event */
void glut_idle(void);

/* Start glut */
void start_glut(void);

/* Print a string */
void print_string(int x, int y, char *string);

/* Print a string (let choose the color and transp.) */
void print_cstring(int x, int y, float r, float g, float b, float t, char *string);

/* defines our keys symbol to be independent from glut */
/* special: manage mouse click as a key-event */
#define KEY_MOUSE1 9991
#define KEY_MOUSE2 9992
#define KEY_MOUSE3 9993
#define KSPE    1000
#define KEY_NULL 0
#define KEY_LAST 126  /* last valid character */
#define KEY_F1  (KSPE+GLUT_KEY_F1)
#define KEY_F2  (KSPE+GLUT_KEY_F2)
#define KEY_F3  (KSPE+GLUT_KEY_F3)
#define KEY_F4  (KSPE+GLUT_KEY_F4)
#define KEY_F5  (KSPE+GLUT_KEY_F5)
#define KEY_F6  (KSPE+GLUT_KEY_F6)
#define KEY_F7  (KSPE+GLUT_KEY_F7)
#define KEY_F8  (KSPE+GLUT_KEY_F8)
#define KEY_F9  (KSPE+GLUT_KEY_F9)
#define KEY_F10 (KSPE+GLUT_KEY_F10)
#define KEY_F11 (KSPE+GLUT_KEY_F11)
#define KEY_F12 (KSPE+GLUT_KEY_F12)
#define KEY_RETURN 13
#define KEY_SPACE  ' '
#define KEY_TAB    9
#define KEY_UP     (KSPE+GLUT_KEY_UP)
#define KEY_LEFT   (KSPE+GLUT_KEY_LEFT)
#define KEY_RIGHT  (KSPE+GLUT_KEY_RIGHT)
#define KEY_DOWN   (KSPE+GLUT_KEY_DOWN)
#define KEY_ESC    27
#define KEY_PGUP   (KSPE+GLUT_KEY_PAGE_UP)
#define KEY_PGDN   (KSPE+GLUT_KEY_PAGE_DOWN)
#define KEY_HOME   (KSPE+GLUT_KEY_HOME)
#define KEY_END    (KSPE+GLUT_KEY_END)
#define KEY_INSERT (KSPE+GLUT_KEY_INSERT)
#define KEY_BACKSPACE 8
#define KEY_DEL    127
#define KEY_PLUS   '+'
#define KEY_MINUS  '-'
#define KEY_a      'a'
#define KEY_b      'b'
#define KEY_c      'c'
#define KEY_d      'd'
#define KEY_e      'e'
#define KEY_f      'f'
#define KEY_g      'g'
#define KEY_h      'h'
#define KEY_i      'i'
#define KEY_j      'j'
#define KEY_k      'k'
#define KEY_l      'l'
#define KEY_m      'm'
#define KEY_n      'n'
#define KEY_o      'o'
#define KEY_p      'p'
#define KEY_q      'q'
#define KEY_r      'r'
#define KEY_s      's'
#define KEY_t      't'
#define KEY_u      'u'
#define KEY_v      'v'
#define KEY_w      'w'
#define KEY_x      'x'
#define KEY_y      'y'
#define KEY_z      'z'
#define KEY_A      'A'
#define KEY_B      'B'
#define KEY_C      'C'
#define KEY_D      'D'
#define KEY_E      'E'
#define KEY_F      'F'
#define KEY_G      'G'
#define KEY_H      'H'
#define KEY_I      'I'
#define KEY_J      'J'
#define KEY_K      'K'
#define KEY_L      'L'
#define KEY_M      'M'
#define KEY_N      'N'
#define KEY_O      'O'
#define KEY_P      'P'
#define KEY_Q      'Q'
#define KEY_R      'R'
#define KEY_S      'S'
#define KEY_T      'T'
#define KEY_U      'U'
#define KEY_V      'V'
#define KEY_W      'W'
#define KEY_X      'X'
#define KEY_Y      'Y'
#define KEY_Z      'Z'
#define KEY_1      '1'
#define KEY_2      '2'
#define KEY_3      '3'
#define KEY_4      '4'
#define KEY_5      '5'
#define KEY_6      '6'
#define KEY_7      '7'
#define KEY_8      '8'
#define KEY_9      '9'
#define KEY_0      '0'
#define KEY_EQUAL  '='
#define KEY__      '_'
#define KEY_DIV    '/'
#define KEY_MULT   '*'
#define KEY_POINT  '.'
#define KEY_DOLLAR '$'
#define KEY_AND    '&'
#define KEY_TILDA  '~'
#define KEY_AT     '@'
#define KEY_PERCENT '%'
/*#define KEY_   ''
#define KEY_   ''
#define KEY_   ''
#define KEY_   ''
#define KEY_   ''
#define KEY_   ''
#define KEY_   ''
#define KEY_   ''
#define KEY_   ''
#define KEY_   ''
#define KEY_   ''
#define KEY_   ''
#define KEY_   ''
#define KEY_   ''
#define KEY_   ''*/
/* not finisFhed */





#endif /* __glut_interface_h_ */
