/* NATOW - Tank to tank warfare in a 3D fully destructable world
 *
 * Copyright (C) 2000-2001
 *                     Robert Ancell  <bob27@users.sourceforge.net>
 *                     Yannick Perret <hexasoft@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __round_h__
#define __round_h__

typedef struct _Round Round;

#include "world.h"
#include "map.h"
#include "player_list.h"
#include "game.h"
#include "projectile.h"
#include "trails.h"
#include "explosion.h"
#include "bird.h"
#include "smoke.h"
#include "camera.h"

/* A structure for a game round */
struct _Round
{
  /* What world and map this round is being played in */
  World *world;
  Map *map;

  /* The game this round is part of */
  Game *game;

  /* The current turn */
  int turn, max_turns;

  /* Properties for this round */
  float driving_time;

  /* The camera for this round */
  Camera *camera;

  /* The players in this game */
  PlayerList *players;
  PlayerEntry *current_player_entry;
  Player *current_player;

  /* The projectile, trails, blasts, birds, and smoke in this round */
  Projectile *projectile_list;
  Trail *trail_list;
  Blast *blast_list;
  Bird *bird_list;
  Smoke *smoke_list;
};

/* Start a new round */
int start_round(Game *game);

/* Draw a screen to start a round */
int draw_start_round(Game *game);

/* Manage the input while in the start round screen */
int manage_start_round_input(Game *game, int key);

/* Update everything in the round */
void update_round(Round *round, float dt);

/* Draw the round */
void draw_round(Round *round);

/* See if the round is over, i.e. someone has won (or draw) */
void test_round_end(Round *round);

/* Draw a screen for the end of a round */
int draw_end_round(Round *round);

/* Manage the input when in the end round screen */
int manage_end_round_input(Round *round, int key);

/* End a round */
int end_round(Round *round);

/* Clean up, and start the next round */
int finish_round(Round *round);

/* Manage the input during a round */
int manage_round_input(Round *round, int key);

/* Draw all the objects in the round */
void draw_round(Round *round);

/* Destroy a round */
int free_round(Round *round);

#endif /* __round_h__ */
